@@ -1,5 +1,7 @@
 from linkml_runtime.utils.curienamespace import CurieNamespace
 from rdflib import RDF, RDFS, SKOS, XSD, OWL
+import rdflib_shim
+shim = rdflib_shim.RDFLIB_SHIM
 
 LINKML = CurieNamespace('linkml', 'https://w3id.org/linkml/')
 TCCM = CurieNamespace('tccm', 'https://ontologies.r.us/tccm/')
